SingleDot constructor
const
SingleDot({})
Creates a single dot widget.
The size parameter specifies the diameter of the dot.
The color parameter specifies the color of the dot.
The borderColor parameter specifies the color of the optional border around the dot.
The borderWidth parameter specifies the width of the optional border around the dot.
The gap parameter specifies the horizontal gap around the dot.
Implementation
const SingleDot(
{Key? key,
this.size = 10.0,
this.color = Colors.black,
this.borderColor,
this.borderWidth = 0.0,
this.gap = 0.0})
: super(key: key);