Star constructor

const Star({
  1. Key? key,
  2. double size = 50.0,
  3. Color color = Colors.black,
  4. int numPoints = 5,
})

Creates a star widget.

The size parameter specifies the diameter of the circumscribed circle around the star. The color parameter specifies the color of the star. The numPoints parameter specifies the number of points of the star (default is 5).

Implementation

const Star({
  Key? key,
  this.size = 50.0,
  this.color = Colors.black,
  this.numPoints = 5,
}) : super(key: key);